Pool

Struct Pool 

pub struct Pool<D: Direction<B>, F: Profile, B: PoolDriver> { /* private fields */ }

Implementations

Source

impl<P, T, S, F, B> Pool<Client<P, T, S>, F, B>

pub fn poke_outbound( &mut self, driver: &mut B::Driver, conn_id: SlotId, ) -> Result<(), PushError>

pub fn pump_outbound(&mut self, driver: &mut B::Driver) -> usize

Source

impl<P, T, S, F, B> Pool<Client<P, T, S>, F, B>

pub fn new( direction: Client<P, T, S>, max_conn: usize, slot_id_base: usize, ) -> Result<Self>

pub fn slot_id_range(&self) -> Range<usize>

pub fn conn_slot_count(&self) -> usize

pub fn direction_mut(&mut self) -> &mut Client<P, T, S>

pub fn live_conns(&self) -> impl Iterator<Item = SlotId> + '_

pub fn is_live(&self, conn_id: SlotId) -> bool

pub fn session_mut(&mut self, conn_id: SlotId) -> Option<&mut ClientSession<P>>

pub fn session_with_codec_mut( &mut self, conn_id: SlotId, ) -> Option<(&mut ClientSession<P>, &mut <P::CodecLayer as CodecLayer>::ConnState)>

Out-of-callback access to both the session and the paired codec state.

Note: mutations made through this accessor do not auto-poke the outbound path. After mutating codec state in a way that should produce wire bytes (e.g. triggering a TLS handshake), call Pool::poke_outbound to wake the slot.

Source

impl<P, S, F, B> Pool<Client<P, Tcp, S>, F, B>

pub fn build( protocol: P, connect_source: S, cfg: TcpClientConfig, ) -> Result<Runtime<Self>>

pub fn build_raw( protocol: P, connect_source: S, cfg: TcpClientConfig, _driver: &mut B::Driver, slot_id_base: usize, ) -> Result<Self>

Source

impl<H: ServerProtocol, T: Transport, F: Profile, B: PoolDriver> Pool<Server<H, T>, F, B>

pub fn push_response( &mut self, driver: &mut B::Driver, conn_id: SlotId, bytes: &[u8], close_after: bool, ) -> Result<(), PushError>

Source

impl<H, F, B> Pool<Server<H, Tcp>, F, B>

pub fn build(protocol: H, cfg: TcpServerConfig) -> Result<Runtime<Self>>

pub fn build_raw( protocol: H, cfg: TcpServerConfig, driver: &mut B::Driver, slot_id_base: usize, ) -> Result<Self>

Source

impl<H, T, F, B> Pool<Server<H, T>, F, B>

pub fn slot_id_range(&self) -> Range<usize>

pub fn conn_slot_count(&self) -> usize

pub fn protocol(&self) -> &H

pub fn protocol_mut(&mut self) -> &mut H

pub fn listener_fd(&self) -> &FdHandle