pub struct Pool<D: Direction<B>, F: Profile, B: PoolDriver> { /* private fields */ }Implementations
Sourceimpl<P, T, S, F, B> Pool<Client<P, T, S>, F, B>where
P: ClientProtocol,
T: Transport,
T::Addr: Clone,
S: ConnectSource<T>,
F: Profile,
B: PoolDriver,
impl<P, T, S, F, B> Pool<Client<P, T, S>, F, B>where
P: ClientProtocol,
T: Transport,
T::Addr: Clone,
S: ConnectSource<T>,
F: Profile,
B: PoolDriver,
pub fn poke_outbound( &mut self, driver: &mut B::Driver, conn_id: SlotId, ) -> Result<(), PushError>
pub fn pump_outbound(&mut self, driver: &mut B::Driver) -> usize
Sourceimpl<P, T, S, F, B> Pool<Client<P, T, S>, F, B>where
P: ClientProtocol,
T: Transport,
T::Addr: Clone,
S: ConnectSource<T>,
F: Profile,
B: PoolDriver,
impl<P, T, S, F, B> Pool<Client<P, T, S>, F, B>where
P: ClientProtocol,
T: Transport,
T::Addr: Clone,
S: ConnectSource<T>,
F: Profile,
B: PoolDriver,
pub fn new( direction: Client<P, T, S>, max_conn: usize, slot_id_base: usize, ) -> Result<Self>
pub fn slot_id_range(&self) -> Range<usize>
pub fn conn_slot_count(&self) -> usize
pub fn direction_mut(&mut self) -> &mut Client<P, T, S>
pub fn live_conns(&self) -> impl Iterator<Item = SlotId> + '_
pub fn is_live(&self, conn_id: SlotId) -> bool
pub fn session_mut(&mut self, conn_id: SlotId) -> Option<&mut ClientSession<P>>
Sourcepub fn session_with_codec_mut(
&mut self,
conn_id: SlotId,
) -> Option<(&mut ClientSession<P>, &mut <P::CodecLayer as CodecLayer>::ConnState)>
pub fn session_with_codec_mut( &mut self, conn_id: SlotId, ) -> Option<(&mut ClientSession<P>, &mut <P::CodecLayer as CodecLayer>::ConnState)>
Out-of-callback access to both the session and the paired codec state.
Note: mutations made through this accessor do not auto-poke the
outbound path. After mutating codec state in a way that should produce
wire bytes (e.g. triggering a TLS handshake), call
Pool::poke_outbound to wake the slot.
Sourceimpl<H: ServerProtocol, T: Transport, F: Profile, B: PoolDriver> Pool<Server<H, T>, F, B>
impl<H: ServerProtocol, T: Transport, F: Profile, B: PoolDriver> Pool<Server<H, T>, F, B>
Sourceimpl<H, T, F, B> Pool<Server<H, T>, F, B>
impl<H, T, F, B> Pool<Server<H, T>, F, B>
pub fn slot_id_range(&self) -> Range<usize>
pub fn conn_slot_count(&self) -> usize
pub fn protocol(&self) -> &H
pub fn protocol_mut(&mut self) -> &mut H
pub fn listener_fd(&self) -> &FdHandle